@@ -61,7 +61,8 @@ M2C = function(data, BadStart, nchains, method, niter, lambda.min){
             return(R)
         }
         else {
-            R = dmixedvonmises(data, mu1 = circular(params[1]), mu2 = circular(0), kappa1 = params[2], kappa2 = 0, prop = params[3])
+        	P = circularp(data)
+            R = dmixedvonmises(data, mu1 = as.circular(params[1], control.circular = P), mu2 = as.circular(0, control.circular = P), kappa1 = params[2], kappa2 = 0, prop = params[3])
             R = -sum(log(R))
             return(R)
         }
